@@ -810,5 +810,42 @@ class SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         $sftp->get('test.txt', function ($data) {
         }, 0, 1);
         $this->assertTrue(true);
+
+        return $sftp;
+    }
+
+    /**
+     * @depends testPasswordLogin
+     */
+    public function testStatVfs($sftp)
+    {
+        $sftp->put('test.txt', 'aaaaa');
+        $stat = $sftp->statvfs('test.txt');
+
+        $this->assertArrayHasKey('bsize', $stat);
+        $this->assertArrayHasKey('frsize', $stat);
+        $this->assertArrayHasKey('blocks', $stat);
+        $this->assertArrayHasKey('bfree', $stat);
+        $this->assertArrayHasKey('bavail', $stat);
+        $this->assertArrayHasKey('files', $stat);
+        $this->assertArrayHasKey('ffree', $stat);
+        $this->assertArrayHasKey('favail', $stat);
+        $this->assertArrayHasKey('fsid', $stat);
+        $this->assertArrayHasKey('flag', $stat);
+        $this->assertArrayHasKey('namemax', $stat);
+
+        $this->assertSame(255, $stat['namemax']);
+    }
+
+    /**
+     * @depends testPasswordLogin
+     */
+    public function testPosixRename($sftp)
+    {
+        $sftp->put('test1.txt', 'aaaaa');
+        $sftp->put('test2.txt', 'bbbbb');
+
+        $sftp->posix_rename('test1.txt', 'test2.txt');
+        $this->assertSame('aaaaa', $sftp->get('test2.txt'));
     }
 }
