@@ -6,10 +6,13 @@
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
+namespace phpseclib3\Tests\Functional\Net;
+
 use phpseclib3\Net\SSH2;
 use phpseclib3\System\SSH\Agent;
+use phpseclib3\Tests\PhpseclibFunctionalTestCase;
 
-class Functional_Net_SSH2AgentTest extends PhpseclibFunctionalTestCase
+class SSH2AgentTest extends PhpseclibFunctionalTestCase
 {
     public static function setUpBeforeClass()
     {
@@ -24,7 +27,7 @@ class Functional_Net_SSH2AgentTest extends PhpseclibFunctionalTestCase
     public function testAgentLogin()
     {
         $ssh = new SSH2($this->getEnv('SSH_HOSTNAME'));
-        $agent = new Agent;
+        $agent = new Agent();
 
         $this->assertTrue(
             $ssh->login($this->getEnv('SSH_USERNAME'), $agent),
