@@ -1,13 +1,14 @@
 <?php
+
 /**
  * @author    Andreas Fischer <bantu@phpbb.com>
  * @copyright 2013 Andreas Fischer
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib3\Crypt\Common\BlockCipher;
+namespace phpseclib3\Tests\Unit\Crypt\AES;
 
-class Unit_Crypt_AES_PurePHPTest extends Unit_Crypt_AES_TestCase
+class PurePHPTest extends TestCase
 {
     protected function setUp()
     {
