@@ -33,6 +33,24 @@ class SSH2UnitTest extends PhpseclibTestCase
         ];
     }
 
+    /**
+     * @requires PHPUnit < 10
+     * Verify that MASK_* constants remain distinct
+     */
+    public function testBitmapMasks()
+    {
+        $reflection = new \ReflectionClass(SSH2::class);
+        $masks = array_filter($reflection->getConstants(), function ($k) {
+            return strpos($k, 'MASK_') === 0;
+        }, ARRAY_FILTER_USE_KEY);
+        $bitmap = 0;
+        foreach ($masks as $mask => $bit) {
+            $this->assertEquals(0, $bitmap & $bit, "Got unexpected mask {$mask}");
+            $bitmap |= $bit;
+            $this->assertEquals($bit, $bitmap & $bit, "Absent expected mask {$mask}");
+        }
+    }
+
     /**
      * @dataProvider formatLogDataProvider
      * @requires PHPUnit < 10
@@ -384,6 +402,31 @@ class SSH2UnitTest extends PhpseclibTestCase
         self::callFunc($ssh, 'send_channel_packet', [1, 'hello world']);
     }
 
+    /**
+     * @requires PHPUnit < 10
+     */
+    public function testDisconnectHelper()
+    {
+        $ssh = $this->getMockBuilder('phpseclib3\Net\SSH2')
+            ->disableOriginalConstructor()
+            ->setMethods(['__destruct', 'isConnected', 'send_binary_packet'])
+            ->getMock();
+        $ssh->expects($this->once())
+            ->method('isConnected')
+            ->willReturn(true);
+        $ssh->expects($this->once())
+            ->method('send_binary_packet')
+            ->with($this->isType('string'))
+            ->willReturnCallback(function () use ($ssh) {
+                self::callFunc($ssh, 'disconnect_helper', [1]);
+                throw new \Exception('catch me');
+            });
+
+        $this->assertEquals(0, self::getVar($ssh, 'bitmap'));
+        self::callFunc($ssh, 'disconnect_helper', [1]);
+        $this->assertEquals(0, self::getVar($ssh, 'bitmap'));
+    }
+
     /**
      * @return SSH2
      */
